========
Dataproc
========

DataprocUtility
---------------

.. autoclass:: gwrappy.dataproc.DataprocUtility
    :members:


Misc Classes/Functions
----------------------

.. autoclass:: gwrappy.dataproc.utils.OperationResponse
    :members:

.. autoclass:: gwrappy.dataproc.utils.JobResponse
    :members:
